"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const base_1 = require("../lib/base");
const command_1 = require("@oclif/command");
const chalk = require('chalk');
const cli_ux_1 = require("cli-ux");
class Explore extends base_1.default {
    async doCommand(userConfig, client) {
        const { flags } = this.parse(Explore);
        let n = 5;
        if (flags.number) {
            const input_n = flags.number;
            if (input_n >= 1 && input_n <= 20) {
                n = input_n;
            }
            else if (input_n > 20) {
                n = 20;
            }
            else {
                n = 5;
            }
        }
        // start the spinner
        cli_ux_1.default.action.start(`getting latest ${n} talks...`);
        const resp = await client.get('talks/explore');
        // stop the spinner
        cli_ux_1.default.action.stop(); // shows 'starting a process... done'
        // sort by id desc
        const origData = resp.data.data;
        origData.slice(0, n).reverse().forEach((talk) => {
            // likes
            let likes_str = '';
            if (talk.likes && talk.likes > 0) {
                likes_str = chalk.redBright(`\t♥ ${talk.likes}`);
            }
            this.log(`${chalk.blue(talk.name)}\t${chalk.grey(talk.created_at)}${likes_str}:`);
            if (talk.tags && talk.tags.length > 0) {
                const tag_str = talk.tags.map((t) => '#' + t + '#').reduce((a, b) => a + ', ' + b);
                this.log(`${chalk.yellow(tag_str)}`);
            }
            this.log(`${talk.text}\n------------------------------\n`);
        });
    }
}
exports.default = Explore;
Explore.description = 'explore talks on giki.app';
Explore.flags = {
    help: command_1.flags.help({ char: 'h' }),
    // flag with a value (-n, --number=VALUE)
    number: command_1.flags.integer({ char: 'n', description: 'number of talks to explore, [1-20], default 5' }),
};
