"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const base_1 = require("../lib/base");
const command_1 = require("@oclif/command");
const chalk = require('chalk');
const cli_ux_1 = require("cli-ux");
const PicGo = require('picgo');
const picgo = new PicGo();
class New extends base_1.default {
    async uploadImage(imagePath) {
        return new Promise((resolve, reject) => {
            picgo.on('finished', (ctx) => resolve(ctx.output));
            picgo.on('error', (err) => {
                this.log(chalk.red('failed to upload image'));
                reject(err);
            });
            picgo.upload([imagePath]);
        });
    }
    async doCommand(userConfig, client) {
        const { args, flags } = this.parse(New);
        const actions = [];
        if (flags.action) {
            actions.push(flags.action);
        }
        let tags = [];
        if (flags.tag && flags.tag.length > 0) {
            tags = flags.tag;
        }
        let text = args.text;
        let image_url = '';
        if (flags.image) {
            const img_resp = await this.uploadImage(flags.image);
            // only get first image url
            image_url = img_resp[0].imgUrl;
            // upload image must success to continue
            if (!image_url) {
                this.log(chalk.red('failed to upload image, please check your picgo config'));
                return;
            }
            text = `${text}\n\n![](${image_url})\n`;
        }
        cli_ux_1.default.action.start('creating new giki');
        await client.post('talks/create', {
            text: text,
            tags: tags,
            actions: actions,
        });
        cli_ux_1.default.action.stop();
        // here we believe the request is success, otherwise the cli.action will exit with non-0 value and cannot reaches here
        this.log(chalk.green('giki created!'));
    }
}
exports.default = New;
New.description = 'post a new giki under your account';
New.flags = {
    help: command_1.flags.help({ char: 'h' }),
    tag: command_1.flags.string({ char: 't', description: 'tag[s] of the new giki, you can set more than 1 tags but you must put the -t flag after the text argument, like: `giki new "text to talk" -t <tag1> -t <tag2>`', multiple: true }),
    action: command_1.flags.string({ char: 'a', description: 'action of the new giki', options: ['weibo', 'i'] }),
    image: command_1.flags.string({ char: 'i', description: 'image file path to upload, note that image uploading is powered by https://github.com/PicGo/PicGo-Core, please make sure you have the correct configuration.' }),
};
New.args = [{ name: 'text', required: true, description: 'text to giki' }];
